#!/bin/sh -e

VERSION=$2
TAR=../libcommons-lang3-java_$VERSION.orig.tar.gz
DIR=libcommons-lang3-java-$VERSION
TAG=$(echo "LANG_$VERSION" | sed -re's/\./_/')

svn export http://svn.apache.org/repos/asf/commons/proper/lang/tags/${TAG} $DIR
GZIP=--best tar -c -z -f $TAR --exclude '*.jar' --exclude '*.class' $DIR
rm -rf $DIR ../$TAG
